@@ -1,7 +1,9 @@
+from __future__ import absolute_import
+from pony.py23compat import iteritems
+
 import os
 os.environ["NLS_LANG"] = "AMERICAN_AMERICA.UTF8"
 
-from types import NoneType
 from datetime import date, datetime
 from decimal import Decimal
 from uuid import UUID
@@ -14,6 +16,8 @@ from pony.orm.dbschema import DBSchema, DBObject, Table, Column
 from pony.orm.dbapiprovider import DBAPIProvider, wrap_dbapi_exceptions, get_version_tuple
 from pony.utils import throw
 
+NoneType = type(None)
+
 class OraTable(Table):
     def get_objects_to_create(table, created_tables=None):
         result = Table.get_objects_to_create(table, created_tables)
@@ -57,7 +61,7 @@ BEGIN
   IF :new.%s IS NULL THEN
     SELECT %s.nextval INTO :new.%s FROM DUAL;
   END IF;
-END;""".strip()
+END""".strip()
 
 class OraTrigger(DBObject):
     typename = 'Trigger'
@@ -320,7 +324,7 @@ class OraProvider(DBAPIProvider):
         return name[:provider.max_name_len].upper()
 
     def normalize_vars(provider, vars, vartypes):
-        for name, value in vars.iteritems():
+        for name, value in iteritems(vars):
             if value == '':
                 vars[name] = None
                 vartypes[name] = NoneType
@@ -469,7 +473,7 @@ def get_inputsize(arg):
 def set_input_sizes(cursor, arguments):
     if type(arguments) is dict:
         input_sizes = {}
-        for name, arg in arguments.iteritems():
+        for name, arg in iteritems(arguments):
             size = get_inputsize(arg)
             if size is not None: input_sizes[name] = size
         cursor.setinputsizes(**input_sizes)
